==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/jsp/QPageData.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.jsp;

import com.caucho.log.Log;
import com.caucho.vfs.TempStream;

import javax.servlet.jsp.tagext.PageData;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Logger;

public class QPageData extends PageData {
  private static final Logger log = Log.open(QPageData.class);
  
  private TempStream _ts;

  /**
   * Creates a new page data.
   */
  public QPageData(TempStream ts)
  {
    _ts = ts;
  }

  /**
   * Returns an input stream to the JSP page.
   */
  public InputStream getInputStream()
  {
    try {
      return _ts.openReadAndSaveBuffer();
    } catch (IOException e) {
      return null;
    }
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/jsp/QPageData.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.jsp;

import com.caucho.vfs.TempStream;

import javax.servlet.jsp.tagext.PageData;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Logger;

public class QPageData extends PageData {
  private static final Logger log
    = Logger.getLogger(QPageData.class.getName());
  
  private TempStream _ts;

  /**
   * Creates a new page data.
   */
  public QPageData(TempStream ts)
  {
    _ts = ts;
  }

  /**
   * Returns an input stream to the JSP page.
   */
  public InputStream getInputStream()
  {
    try {
      return _ts.openReadAndSaveBuffer();
    } catch (IOException e) {
      return null;
    }
  }
}
